# Note on building bbdb with support for VM: if support for VM in bbdb is
# required, then the source elisp for VM must be installed at build time. If
# support for BBDB is required in VM, then the BBDB source elisp must be present
# at build time. Hence there is a circular BuildRequires and bootstrapping is
# required. The way to do this is (i) build emacs-vm without BuildRequires:
# emacs-bbdb (ii) build emacs-bbdb with BuildRequires: emacs-vm (iii)
# rebuild emacs-vm with BuildRequires: emacs-bbdb.  Or vice versa.
%define vmsupport 1

%define lispdir %{_emacs_sitelispdir}/bbdb
%define texdir %{_datadir}/texmf/tex/generic/bbdb
	

Name:           emacs-bbdb
Version:        2.35
Release:        11%{?dist}
Epoch:		1
Summary:        A contact management utility for use with Emacs
Summary(sv):    Ett verktyg för att hantera kontakter i Emacs
Group:          Applications/Internet
License:        GPLv2+
URL:            http://bbdb.sourceforge.net/
Requires:       emacs(bin) >= %{_emacs_version}

Source0:        bbdb-2.35.tar.gz

# This patch pulls in upstream changes to Makefile.in in the lisp directory (up
# to revision 1.17). No need to upstream therefore, and should be removed for bbdb-2.36
Patch0:		bbdb-2.35-fix_lisp_makefile.patch

# Fix mh-cache-key to work with Emacs 24
Patch1: 	bbdb-2.35-emacs24-fix-mh-cache-key.patch

# Fix incorrect dependence on the return value from run-hook-with-args
# Reported upstream:
# http://www.mail-archive.com/bbdb-info%40lists.sourceforge.net/msg05749.html
Patch2:		bbdb-2.35-run-hook-with-args.patch

# Remove undefined "bbdb-" as default value in menu selection.
# Reported ustreams but ignored:
# http://savannah.nongnu.org/bugs/?38178
Patch3:		bbdb-2.35-remove-undefined-default.patch

BuildArch:      noarch
BuildRequires:  emacs texinfo-tex

%if %{vmsupport}
BuildRequires:  emacs-vm
%endif

# This obsolete and provides can be removed in Fedora 20
Obsoletes:	%{name}-el < 1:2.35-7
Provides:	%{name}-el <= 1:2.35-6

%description 
The Insidious Big Brother Database (BBDB) is a contact management
utility created by Jamie Zawinski for use with Emacs. It is tightly
integrated with several mail and news readers, allowing it to create
database entries directly from mail and news messages. As is usual
with applications for Emacs, this record creation can be configured in
many ways, ranging from a boolean create/don't create setting to
creation based on the result of a user-supplied function.

Database records can be used to store many types of information, from
name and address to URLs and X-Face images. This information can be
displayed when a message from an entity named in a database record is
received. In addition, messages from database members can be tagged in
the Gnus Summary Buffer, and Gnus scoring can be configured based on
the contents of database records. Supercite citations can even be
preset through the use of records in the BBDB.

%description -l sv
BBDB (The Insidious Big Brother Database) är ett verktyg för att
hantera kontakter i Emacs skapat av Jamie Zawinski.  Det är nära
integrerat med flera post- och nyhetsläsare, vilket gör att det kan
skapa databasposter direkt från post- och nyhetsmeddelanden.  Som
vanligt med program till Emacs kan detta skapande av poster
konfigureras på olika sätt, från en boolesk inställning skapa/skapa
inte till att en funktion som användaren anger styr om poster skall
skapas.

Databasposter kan användas för att lagra många olika sorters
information, från namn och adress till URL:ar och X-Face-bilder.
Denna information kan visas när ett meddelande tas emot från personen
som är namngiven i databasposten.  Dessutom kan meddelanden från
databasmedlemmar taggas i Gnus sammanfattningsbuffert, och Gnus
poängsättning kan konfigureras baserat på innehållet i databasposten.
Supercite-citat kan till och med fördefinieras med poster i BBDB.

%prep 
%setup -q -n bbdb-%{version}

# Correct encoding of info file and ChangeLog
for i in texinfo/bbdb.texinfo ChangeLog ; do
    iconv --from=ISO-8859-1 --to=UTF-8 $i > $i.new
    mv $i.new $i
done

%patch0 -p 1 -b .fix_lisp_makefile
%patch1 -p 0 -b .mh-cache-key
%patch2 -p 0 -b .run-hook-with-args
%patch3 -p 0 -b .remove-undefined-default

%build
# Note --enable-developer simply gives more verbose output during building,
# handy for debugging
%if %{vmsupport}
%configure --with-vm-dir=%{_emacs_sitelispdir}/vm --enable-developer
%else
%configure --enable-developer
%endif

# Note: make %{?_smp_mflags} fails.
make all

%install
# There is no usable install make rule - install by hand.
install -d $RPM_BUILD_ROOT%{lispdir}
install -p -m 0644 lisp/*.{elc,el} $RPM_BUILD_ROOT%{lispdir}
install -d $RPM_BUILD_ROOT%{texdir}
install -p -m 0644 tex/*.tex $RPM_BUILD_ROOT%{texdir}
install -d $RPM_BUILD_ROOT%{_infodir}
install -p -m 0644 texinfo/bbdb.info $RPM_BUILD_ROOT%{_infodir}

# Create and install init file
install -d $RPM_BUILD_ROOT%{_emacs_sitestartdir}
cat > $RPM_BUILD_ROOT%{_emacs_sitestartdir}/bbdb-mode-init.el << EOF
(require 'bbdb-autoloads)
EOF

# Remove some unpackaged files
rm -f bits/make.bat
rm -f utils/Makefile*

# The perl scripts in the utils directory are packaged as docs, and so chmod -x
# them. Also correct the hash-bang.
find -name '*.pl' -exec chmod -x {} \;
find -name '*.pl' -exec sed -i -e 's|#![a-z/]*|/usr/bin/perl|g' {} \;

%post
/sbin/install-info %{_infodir}/bbdb.info %{_infodir}/dir 2>/dev/null || :

%preun
if [ $1 -eq 0 ]; then
  /sbin/install-info --delete %{_infodir}/bbdb.info %{_infodir}/dir 2>/dev/null || :
fi

%files
%doc bits misc utils ChangeLog 
%doc %{_infodir}/bbdb.info.gz
%{lispdir}/
%{texdir}/*.tex
%{_emacs_sitestartdir}/bbdb-mode-init.el


%changelog
* Mon Jan 28 2013 Göran Uddeborg <goeran@uddeborg.se> 1:2.35-11
- Remove undefined default function in menu selection for customizable
  variables.

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.35-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul  5 2012 Göran Uddeborg <goeran@uddeborg.se> 1:2.35-9
- Remove obsolete "clean" and "defattr".
- Update references to the removed -el packages in spec file comments.
- Obsolete -el subpackages strictly less than release 7 rather than
  less than or equal to release 6.  Otherwise release 6 packages with
  a dist tag will be considered newer. (BZ #832822)
- Run bbdb-canonicalize-net-hook manually rather than via
  run-hook-with-args in order to get the desired return value.  (BZ #835318)
- Swedish translation of the summary and description added.

* Tue Jun  5 2012 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1:2.35-8
- Change BuildRequires for emacs-vm-el to emacs-vm

* Tue Jun  5 2012 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1:2.35-7
- Remove separate emacs-bbdb-el sub-package
- Add patch to work with Emacs 24 (BZ #828582)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.35-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.35-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Dec 26 2009 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1:2.35-4
- Update spec file to use macros installed with the emacs package rather than
  pkgconfig stuff
- Remove BuildRoot and rm -rf buildroot from install section

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.35-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.35-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Nov  9 2008 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 1:2.35-1
- Revert to 2.35 release in order to address BZ 467909 and 467911
- Add bbdb-2.35-fix_lisp_makefile.patch in order to fix build problems
- Add epoch to avoid problems with package updating

* Thu Nov  6 2008 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.36-0.1.20080928cvs
- Rename snapshot to reflect the fact that it is a 2.36 pre-release rather than
  a post 2.35 snapshot
- Fix day of previous spec file changelog entry
- Added a patch to revert upstream SVN revision 106 (which is suitable for
  emacs>=23) (BZ 467909)

* Sat Sep 29 2008 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-9.20080928cvs
- Update to current CVS snapshot, fixing several bugs
- Ensure that bbdb-vm.elc is built and installed (BZ 462875)
- Add --enable-developer to configure for more verbose build info

* Fri Sep 28 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-8
- Correct encoding of ChangeLog and info files
- Correct hash bang in perl scripts which are installed as docs
- correct spelling mistake in description

* Sun Sep  9 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-7
- Add init file

* Sun Sep  9 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-6
- Add sensible defaults for the case that there is no Emacs
  pkg-config file at build time

* Thu Sep  6 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-5
- Add changes to comply with Emacs add-on packaging guidelines

* Tue May 29 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-4
- Add BuildRequires: emacs-vm-el
- Add macro to determine emacsversion at package build time
- Add Requires emacs-common >= emacsversion
- Add notes about bootstrapping with VM to top of spec file

* Mon May  7 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-3
- Convert info file to correct encoding (Tom Tromey)
- Use install rather than mkdir and cp to install files

* Sat Feb 10 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-2
- Added Requires: tetex, since bbd-print requires TeX to be installed

* Sat Feb  3 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 2.35-1
- Initial package


